.. module:: enaml.widgets.bounded_time

==========================
enaml.widgets.bounded_time
==========================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    BoundedTime


.. autoclass:: BoundedTime
